@@ -29,10 +29,38 @@ def test_empty_str():
     assert str(AABBTree()) == empty_str
 
 
+def test_str_str():
+    aabb = standard_aabbs()[0]
+    value = 7
+    leaf = AABBTree(aabb)
+    tree = AABBTree(aabb=aabb, value=value, left=leaf, right=leaf)
+    fmt = 'AABB: {}\nValue: {}\nLeft:\n{}\nRight:\n{}'
+    assert str(tree) == fmt.format(str(aabb), str(value), leaf.__str__(1),
+                                   leaf.__str__(1))
+
+
 def test_empty_repr():
     assert repr(AABBTree()) == 'AABBTree()'
 
 
+def test_leaf_repr():
+    aabb = standard_aabbs()[0]
+    tree = AABBTree()
+    tree.add(aabb)
+    assert repr(tree) == 'AABBTree(aabb={})'.format(repr(aabb))
+
+
+def test_str_repr():
+    aabb = 'a'
+    value = 'v'
+    left = 'left'
+    right  = 'right'
+    tree = AABBTree(aabb=aabb, value=value, left=left, right=right)
+    fmt = 'AABBTree(aabb={}, value={}, left={}, right={})'
+    assert repr(tree) == fmt.format(repr(aabb), repr(value), repr(left),
+                                    repr(right))
+
+
 def test_eq():
     tree = AABBTree()
     tree.add(AABB([(2, 3)]))
@@ -115,6 +143,10 @@ def test_does_overlap():
     aabb6 = AABB([(0, 1), (5, 6)])
     aabb7 = AABB([(6.5, 6.5), (5.5, 5.5)])
 
+    not_tree = AABBTree()
+    not_tree.add(aabb6)
+    not_tree.add(aabb7)
+
     for aabb in (aabb5, aabb6, aabb7):
         for m in ('DFS', 'BFS'):
             assert not AABBTree().does_overlap(aabb, method=m)
@@ -122,14 +154,31 @@ def test_does_overlap():
     aabbs = standard_aabbs()
     for indices in itertools.permutations(range(4)):
         tree = AABBTree()
-        for i in indices:
+        alt_tree = AABBTree()
+        for i_ind, i in enumerate(indices):
             tree.add(aabbs[i])
+            alt_tree.add(aabbs[i_ind])
 
         for m in ('DFS', 'BFS'):
+            assert tree.does_overlap(tree, method=m)
+            assert alt_tree.does_overlap(tree, method=m)
+            assert tree.does_overlap(alt_tree, method=m)
+
             assert tree.does_overlap(aabb5, method=m)
             assert not tree.does_overlap(aabb6, method=m)
             assert not tree.does_overlap(aabb7, method=m)
 
+            assert not tree.does_overlap(not_tree, method=m)
+            assert not not_tree.does_overlap(tree, method=m)
+
+
+def test_does_overlap_error():
+    method = -1
+    aabbs  = standard_aabbs()
+    tree = standard_tree()
+    with pytest.raises(ValueError):
+        tree.does_overlap(aabbs[0], method=method)
+
 
 def test_overlap_aabbs():
     aabbs = standard_aabbs()
@@ -139,12 +188,18 @@ def test_overlap_aabbs():
     aabb6 = AABB([(0, 1), (5, 6)])
     aabb7 = AABB([(6.5, 6.5), (5.5, 5.5)])
 
+    not_tree = AABBTree()
+    not_tree.add(aabb6)
+    not_tree.add(aabb7)
+
     for indices in itertools.permutations(range(4)):
         tree = AABBTree()
         for i in indices:
             tree.add(aabbs[i], values[i])
 
         for m in ('DFS', 'BFS'):
+            assert all([box in tree.overlap_aabbs(tree, method=m)
+                        for box in aabbs])
             aabbs5 = tree.overlap_aabbs(aabb5, method=m)
             assert len(aabbs5) == 2
             for aabb in aabbs5:
@@ -153,10 +208,21 @@ def test_overlap_aabbs():
             assert tree.overlap_aabbs(aabb6) == []
             assert tree.overlap_aabbs(aabb7) == []
 
+            assert tree.overlap_aabbs(not_tree, method=m) == []
+            assert not_tree.overlap_aabbs(tree, method=m) == []
+
     for m in ('DFS', 'BFS'):
         assert AABBTree(aabb5).overlap_aabbs(aabb7, method=m) == []
 
 
+def test_overlap_aabbs_error():
+    method = -1
+    aabbs  = standard_aabbs()
+    tree = standard_tree()
+    with pytest.raises(ValueError):
+        tree.overlap_aabbs(aabbs[0], method=method)
+
+
 def test_overlap_values():
     aabbs = standard_aabbs()
     values = ['value 1', 3.14, None, None]
@@ -183,6 +249,19 @@ def test_overlap_values():
         assert AABBTree(aabb5).overlap_values(aabb7, method=m) == []
 
 
+def test_overlap_values_error():
+    method = -1
+    aabbs  = standard_aabbs()
+    tree = standard_tree()
+    with pytest.raises(ValueError):
+        tree.overlap_values(aabbs[0], method=method)
+
+
+def test_depth():
+    assert AABBTree().depth == 0
+    assert standard_tree().depth == 2
+
+
 def standard_aabbs():
     aabb1 = AABB([(0, 1), (0, 1)])
     aabb2 = AABB([(3, 4), (0, 1)])
